pub struct Function {
pub symbol: u32,
pub locals: Vec<(u32, ValType)>,
pub code: Vec<u8>,
pub fixups: Vec<Fixup>,
pub export: Option<String>,
}Expand description
A function that this object defines.
Fields
symbol: u32The index of its symbol, which is a function symbol.
locals: Vec<(u32, ValType)>The locals after the parameters, as runs of one type.
code: Vec<u8>The instructions, with the end that closes the body.
fixups: Vec<Fixup>export: Option<String>A name for the export section of this object, from export_name.