pub struct Import {
pub module: String,
pub field: String,
}Expand description
The module and the field of an import when they are not env and the symbol name, which is
what import_module and import_name ask for.
Fields
module: Stringfield: StringTrait Implementations
impl Eq for Import
impl StructuralPartialEq for Import